@@ -178,14 +178,33 @@ public:
 
 null_logger FZ_PUBLIC_SYMBOL & get_null_logger();
 
-/// A simple logger that writes to stdout
+/**
+ * \brief A simple logger that writes to stdout
+ *
+ * Logging will fail for lines that cannot be converted to the current
+ * locale's narrow character encoding.
+ */
 class FZ_PUBLIC_SYMBOL stdout_logger final : public logger_interface
 {
 public:
 	virtual void do_log(logmsg::type, std::wstring &&) override;
 };
 
+/**
+ * \brief A logger that appends to a native_string
+ *
+ * Logging will fail for lines that cannot be converted to native_string.
+ */
+class FZ_PUBLIC_SYMBOL native_string_logger final : public fz::logger_interface
+{
+public:
+	native_string_logger(fz::native_string &str, logmsg::type);
 
+	virtual void do_log(fz::logmsg::type, std::wstring &&) override;
+
+private:
+	fz::native_string &str_;
+};
 }
 
 #endif
